@@ -21,6 +21,7 @@ from neuro_cli.click_types import (
     BUCKET_CREDENTIAL,
     BUCKET_NAME,
     CLUSTER,
+    ORG,
     PlatformURIType,
 )
 from neuro_cli.formatters.bucket_credentials import (
@@ -97,6 +98,7 @@ async def lsbucket(
             uri_fmtr = uri_formatter(
                 username=root.client.username,
                 cluster_name=cluster or root.client.cluster_name,
+                org_name=root.client.config.org_name,
             )
         buckets_fmtr = BucketsFormatter(
             uri_fmtr,
@@ -121,6 +123,11 @@ async def lsbucket(
     type=CLUSTER,
     help="Perform in a specified cluster (the current cluster by default).",
 )
+@option(
+    "--org",
+    type=ORG,
+    help="Perform in a specified org (the current org by default).",
+)
 @option(
     "--name",
     type=BUCKET_NAME,
@@ -132,6 +139,7 @@ async def mkbucket(
     root: Root,
     name: Optional[str] = None,
     cluster: Optional[str] = None,
+    org: Optional[str] = None,
 ) -> None:
     """
     Create a new bucket.
@@ -139,6 +147,7 @@ async def mkbucket(
     bucket = await root.client.buckets.create(
         name=name,
         cluster_name=cluster,
+        org_name=org,
     )
     bucket_fmtr = BucketFormatter(
         str, datetime_formatter=get_datetime_formatter(root.iso_datetime_format)
@@ -153,6 +162,11 @@ async def mkbucket(
     type=CLUSTER,
     help="Perform in a specified cluster (the current cluster by default).",
 )
+@option(
+    "--org",
+    type=ORG,
+    help="Perform in a specified org (the current org by default).",
+)
 @option(
     "--name",
     type=BUCKET_NAME,
@@ -254,6 +268,7 @@ async def importbucket(
     gcp_sa_credential: Optional[str] = None,
     name: Optional[str] = None,
     cluster: Optional[str] = None,
+    org: Optional[str] = None,
 ) -> None:
     """
     Import an existing bucket.
@@ -302,6 +317,7 @@ async def importbucket(
         credentials=credentials,
         name=name,
         cluster_name=cluster,
+        org_name=org,
     )
     bucket_fmtr = BucketFormatter(
         str, datetime_formatter=get_datetime_formatter(root.iso_datetime_format)
@@ -332,6 +348,7 @@ async def statbucket(
         uri_fmtr = uri_formatter(
             username=root.client.username,
             cluster_name=cluster or root.client.cluster_name,
+            org_name=root.client.config.org_name,
         )
     bucket_fmtr = BucketFormatter(
         uri_fmtr, datetime_formatter=get_datetime_formatter(root.iso_datetime_format)
@@ -407,7 +424,7 @@ async def set_bucket_publicity(
     root: Root, cluster: Optional[str], bucket: str, public_level: str
 ) -> None:
     """
-    Change public access settings for bucket BUCKET.
+    Change public access settings for BUCKET
 
     Examples:
 
@@ -463,6 +480,7 @@ async def ls(
         uri_fmtr = uri_formatter(
             username=root.client.username,
             cluster_name=root.client.cluster_name,
+            org_name=root.client.config.org_name,
         )
     if format_long:
         # Similar to `ls -l`
@@ -515,6 +533,7 @@ async def glob(root: Root, full_uri: bool, patterns: Sequence[URL]) -> None:
         uri_fmtr = uri_formatter(
             username=root.client.username,
             cluster_name=root.client.cluster_name,
+            org_name=root.client.config.org_name,
         )
     for pattern in patterns:
 
@@ -621,7 +640,7 @@ async def cp(
     progress: bool,
 ) -> None:
     """
-    Simple utility to copy files and directories into and from Blob Storage.
+    Copy blobs into and from Blob Storage.
 
     Either SOURCES or DESTINATION should have `blob://` scheme.
     If scheme is omitted, file:// scheme is assumed. It is currently not possible to
