@@ -45,6 +45,7 @@ from .click_types import (
     JOB_COLUMNS,
     JOB_NAME,
     LOCAL_REMOTE_PORT,
+    ORG,
     PRESET,
     TOP_COLUMNS,
     RemoteImageType,
@@ -157,7 +158,9 @@ async def port_forward(
     root: Root, job: str, local_remote_port: List[Tuple[int, int]]
 ) -> None:
     """
-    Forward port(s) of a running job to local port(s).
+    Forward port(s) of a job.
+
+    Forwards port(s) of a running job to local port(s).
 
     Examples:
 
@@ -245,6 +248,8 @@ async def logs(root: Root, since: str, job: str, timestamps: bool) -> None:
 )
 async def attach(root: Root, job: str, port_forward: List[Tuple[int, int]]) -> None:
     """
+    Attach terminal to a job
+
     Attach local standard input, output, and error streams to a running job.
     """
     id = await resolve_job(
@@ -400,7 +405,9 @@ async def ls(
         uri_fmtr = str
     else:
         uri_fmtr = uri_formatter(
-            username=root.client.username, cluster_name=root.client.cluster_name
+            username=root.client.username,
+            cluster_name=root.client.cluster_name,
+            org_name=root.client.config.org_name,
         )
     if root.quiet:
         formatter: BaseJobsFormatter = SimpleJobsFormatter()
@@ -470,7 +477,9 @@ async def status(root: Root, job: str, full_uri: bool) -> None:
         uri_fmtr = str
     else:
         uri_fmtr = uri_formatter(
-            username=root.client.username, cluster_name=root.client.cluster_name
+            username=root.client.username,
+            cluster_name=root.client.cluster_name,
+            org_name=root.client.config.org_name,
         )
     root.print(
         JobStatusFormatter(
@@ -744,7 +753,9 @@ async def top(
         uri_fmtr = str
     else:
         uri_fmtr = uri_formatter(
-            username=root.client.username, cluster_name=root.client.cluster_name
+            username=root.client.username,
+            cluster_name=root.client.cluster_name,
+            org_name=root.client.config.org_name,
         )
     image_fmtr = image_formatter(uri_formatter=uri_fmtr)
     datetime_fmtr = get_datetime_formatter(root.iso_datetime_format)
@@ -820,6 +831,12 @@ async def kill(root: Root, jobs: Sequence[str]) -> None:
     help="Run job in a specified cluster",
     default=None,
 )
+@option(
+    "--org",
+    type=ORG,
+    help="Run job in a specified org",
+    default=None,
+)
 @option(
     "-s",
     "--preset",
@@ -1004,6 +1021,7 @@ async def run(
     image: RemoteImage,
     preset: str,
     cluster: Optional[str],
+    org: Optional[str],
     extshm: bool,
     http: int,
     http_auth: Optional[bool],
@@ -1030,7 +1048,7 @@ async def run(
     share: Sequence[str],
 ) -> None:
     """
-    Run a job with predefined resources configuration.
+    Run a job
 
     IMAGE docker image name to run in a job.
 
@@ -1051,6 +1069,9 @@ async def run(
     """
     cmd = _fix_cmd("neuro run", "IMAGE -- CMD...", cmd)
     cluster_name = cluster or root.client.cluster_name
+    org_name = org or root.client.config.org_name
+    if org == "NO_ORG":
+        org_name = None
     cluster_config = root.client.config.clusters[cluster_name]
     if not preset:
         preset = next(iter(cluster_config.presets.keys()))
@@ -1086,7 +1107,8 @@ async def run(
         schedule_timeout=schedule_timeout,
         privileged=privileged,
         share=share,
-        cluster_name=cluster or root.client.cluster_name,
+        cluster_name=cluster_name,
+        org_name=org_name,
     )
 
 
@@ -1157,6 +1179,7 @@ async def run_job(
     privileged: bool,
     share: Sequence[str],
     cluster_name: str,
+    org_name: Optional[str],
 ) -> JobDescription:
     if http_auth is None:
         http_auth = True
@@ -1230,6 +1253,7 @@ async def run_job(
         image=image,
         preset_name=preset,
         cluster_name=cluster_name,
+        org_name=org_name,
         entrypoint=entrypoint,
         command=real_cmd,
         working_dir=working_dir,
